@@ -12,7 +12,8 @@ int set_all_promisc()
 	struct ifreq * ifaces;
 	int ifaces_size=8 * sizeof(struct ifreq);
 	struct ifconf param;
-	int sock, i;
+	int sock;
+	unsigned int i;
 
 	sock = socket(PF_INET, SOCK_DGRAM, IPPROTO_IP);
 	if (sock <= 0)
