@@ -57,7 +57,8 @@ mkhash (u_int src, u_short sport, u_int dest, u_short dport)
   u_int res = 0;
   int i;
   u_char data[12];
-  *(u_int *) (data) = src;
+  u_int *stupid_strict_aliasing_warnings=(u_int*)data;
+  *stupid_strict_aliasing_warnings = src;
   *(u_int *) (data + 4) = dest;
   *(u_short *) (data + 8) = sport;
   *(u_short *) (data + 10) = dport;
